"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useRookLogger = void 0;
var _react = require("@xstate/react");
var _LoggerController = require("../controllers/LoggerController");
const useRookLogger = () => {
  const [_, send] = (0, _react.useMachine)(_LoggerController.LoggerController);
  const initLogger = props => {
    const {
      clientUUID,
      environment,
      sdkInfo,
      userID
    } = props;
    send({
      type: 'init',
      payload: {
        clientUUID,
        environment,
        sdkInfo,
        userID
      }
    });
  };
  const sendExtractionLog = content => {
    send({
      type: 'send',
      payload: content
    });
  };
  const sendTransmissionLog = content => {
    send({
      type: 'send',
      payload: content
    });
  };

  /**
   * The `logBoundary` function is a TypeScript function that wraps another function and logs the
   * success or failure of the wrapped function.
   * @param props - The `props` parameter is an object that contains the following properties:
   * @returns The function `logBoundary` returns a `Promise` that resolves to the response from the
   * `fun` function.
   */
  const logBoundary = async props => {
    const {
      fun,
      logSuccess,
      payload,
      logType,
      dataType
    } = props;
    try {
      const response = await fun(payload);
      if (logSuccess) sendLog({
        dataType,
        logType,
        message: {
          status: 'Success',
          description: ''
        }
      });
      return response;
    } catch (error) {
      sendLog({
        dataType,
        logType,
        message: {
          status: 'Failure',
          description: `${error}`
        }
      });
      throw error;
    }
  };

  /**
   * The function `sendLog` sends log messages based on the log type, either extraction or
   * transmission.
   * @param {LogSelector}  - - `dataType`: The type of data being logged.
   */
  const sendLog = _ref => {
    let {
      dataType,
      message,
      logType
    } = _ref;
    if (logType === 'extraction') sendExtractionLog({
      data_type: dataType,
      data_datetime: new Date().toISOString(),
      status: message.status,
      failure_reason: message.description ? message.description : undefined
    });else sendTransmissionLog({
      data_type: dataType,
      data_datetime: new Date().toISOString(),
      server_response: message.description
    });
  };
  return {
    initLogger,
    sendExtractionLog,
    sendTransmissionLog,
    logBoundary
  };
};
exports.useRookLogger = useRookLogger;
//# sourceMappingURL=useRookLogger.js.map